pub enum Command {
Add(Args),
Bump(Args),
Check(Args),
Commit(Args),
Config(Args),
Doctor(Args),
Init(Args),
Push(Args),
Tag(Args),
}Variants
Add(Args)
Add files to staging area interactively
Bump(Args)
Bump version based on Conventional Commits
Check(Args)
Check commits in a range for Conventional Commit compliance
Commit(Args)
Guide the user through writing a Conventional Commit message
Config(Args)
View or edit the current project, global or selected config
Doctor(Args)
Diagnose and fix common issues
Init(Args)
Initialize a project config (prefers .cwizard.toml; supports cwizard.toml)
Push(Args)
Push commits to a remote repository
Tag(Args)
Create a new Git tag (Semantic Versioning) based on Conventional Commits