Module versioning

Module versioning 

Functions

calculate_next_version
Calculate the next version based on commits since last tag.
classify_commits
Classify commits into their bump levels based on commit type and policy. Implements the versioning algorithm from SRS 5.2: