pub struct Runtime { /* private fields */ }Implementations
Sourceimpl Runtime
impl Runtime
pub fn output_config(&self) -> Config
pub fn is_ci(&self) -> bool
pub fn is_non_interactive(&self) -> bool
pub fn is_interactive(&self) -> bool
pub fn mode(&self) -> &RunMode
pub fn options(&self) -> &RuntimeOptions
pub fn options_mut(&mut self) -> &mut RuntimeOptions
pub fn cwd(&self) -> &PathBuf
pub fn in_git_repo(&self) -> bool
pub fn repo_root(&self) -> &PathBuf
pub fn global_paths(&self) -> &RuntimeGlobalPaths
pub fn global_config_path(&self) -> &PathBuf
pub fn global_cache_path(&self) -> &PathBuf
pub fn global_state_path(&self) -> &PathBuf
pub fn state_file_path(&self) -> PathBuf
pub fn sources(&self) -> &AvailableConfigOptions
pub fn sources_mut(&mut self) -> &mut AvailableConfigOptions
pub fn config(&self) -> Option<&ResolvedConfig>
pub fn config_mut(&mut self) -> Option<&mut ResolvedConfig>
pub fn policy(&self) -> &Policy
pub fn policy_mut(&mut self) -> &mut Policy
pub fn set_mode(&mut self, mode: RunMode) -> &mut Self
pub fn set_dry_run(&mut self, dry_run: bool) -> &mut Self
pub fn set_auto_yes(&mut self, auto_yes: bool) -> &mut Self
pub fn set_force(&mut self, force: bool) -> &mut Self
pub fn set_output_envelope(&mut self, envelope: EnvelopeMode) -> &mut Self
pub fn set_output_format(&mut self, format: Format) -> &mut Self
pub fn set_output_color(&mut self, color: ColorMode) -> &mut Self
pub fn set_log_level(&mut self, level: Level) -> &mut Self
pub fn set_cwd(&mut self, cwd: PathBuf) -> &mut Self
pub fn set_in_git_repo(&mut self, in_git_repo: bool) -> &mut Self
pub fn set_repo_root(&mut self, repo_root: PathBuf) -> &mut Self
pub fn set_sources(&mut self, sources: AvailableConfigOptions) -> &mut Self
pub fn set_config(&mut self, config: ResolvedConfig) -> &mut Self
pub fn set_policy(&mut self, policy: Policy) -> &mut Self
pub fn new() -> Self
pub fn resolve_cli_source(&mut self, logger: Option<&dyn LoggerTrait>)
pub fn resolve_repo_source(&mut self, logger: &dyn LoggerTrait)
pub fn resolve_global_source(&mut self)
pub fn resolve_env_source(&mut self)
Sourcepub fn resolve_registry_source(&mut self, logger: &dyn LoggerTrait)
pub fn resolve_registry_source(&mut self, logger: &dyn LoggerTrait)
Resolve and load all available registries from every config layer, marking the one selected via precedence (CLI > ENV > repo > global) as active.
pub fn resolve_available_sources(&mut self, logger: &dyn LoggerTrait)
pub fn resolve_active_config(&mut self, logger: &dyn LoggerTrait) -> Result<()>
pub fn resolve_policy(&mut self)
pub fn explicit_config_path(&self) -> Option<&PathBuf>
pub fn explicit_registry(&self) -> Option<&String>
pub fn explicit_registry_ref(&self) -> Option<&String>
pub fn explicit_registry_section(&self) -> Option<&String>
pub fn set_explicit_config_path(&mut self, path: Option<PathBuf>) -> &mut Self
pub fn set_explicit_registry(&mut self, registry: Option<String>) -> &mut Self
pub fn set_explicit_registry_ref( &mut self, registry_ref: Option<String>, ) -> &mut Self
pub fn set_explicit_registry_section( &mut self, registry_section: Option<String>, ) -> &mut Self
pub fn project_config_path(&self) -> Option<PathBuf>