Module git

Module git 

Structs

Git
TaggedCommits
A tag boundary with all commits that fall in the range (prev_tag, tag]. The tag field is either a version string or "Unreleased" for commits that have not yet been tagged.