pub struct TaggedCommits {
pub tag: String,
pub commits: Vec<CommitSummary>,
}Expand description
A tag boundary with all commits that fall in the range (prev_tag, tag].
The tag field is either a version string or "Unreleased" for commits
that have not yet been tagged.
Fields
tag: Stringcommits: Vec<CommitSummary>Trait Implementations
Sourceimpl Clone for TaggedCommits
impl Clone for TaggedCommits
Sourcefn clone(&self) -> TaggedCommits
fn clone(&self) -> TaggedCommits
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for TaggedCommits
impl RefUnwindSafe for TaggedCommits
impl Send for TaggedCommits
impl Sync for TaggedCommits
impl Unpin for TaggedCommits
impl UnsafeUnpin for TaggedCommits
impl UnwindSafe for TaggedCommits