Module versioning
commit_
wizard
0.0.2
Module versioning
Module Items
Functions
In commit_
wizard::
engine::
capabilities
commit_wizard
::
engine
::
capabilities
Module
versioning
Functions

calculate_
next_
version
Calculate the next version based on commits since last tag.
classify_
commits
Classify commits into their bump levels based on commit type and policy. Implements the versioning algorithm from SRS 5.2: