pub struct RuntimePaths {
pub cwd: PathBuf,
pub global: RuntimeGlobalPaths,
pub in_git_repo: bool,
pub repo_root: Option<PathBuf>,
pub explicit_config_path: Option<PathBuf>,
pub explicit_registry: Option<String>,
pub explicit_registry_ref: Option<String>,
pub explicit_registry_section: Option<String>,
}Fields
cwd: PathBufthe current working directory, determined at runtime
global: RuntimeGlobalPathsthe global paths for config, cache, and state, determined at runtime
in_git_repo: boolwhether we are in a git repository, determined by looking for a .git directory in the current or parent directories
repo_root: Option<PathBuf>default is cwd, but updated if we detect a git repository root
explicit_config_path: Option<PathBuf>an optional explicit config path provided by the user, which overrides all other config sources if present
explicit_registry: Option<String>an optional explicit registry provided by the user, which overrides discovered registries if present
explicit_registry_ref: Option<String>an optional explicit registry ref (e.g. git tag or branch) provided by the user, which overrides the registry config if present
explicit_registry_section: Option<String>an optional explicit registry section provided by the user, which overrides discovered registry sections if present
Implementations
Sourceimpl RuntimePaths
impl RuntimePaths